package com.gic.store.service;

import com.gic.store.dto.StoreDTO;
import com.gic.store.dto.StoreSearchDBDTO;
import com.github.pagehelper.Page;

import java.util.List;

/**
 * @author zhiwj
 * @date 2019/6/27
 */
public interface StoreService {
    /**
     * 保存
     * @param storeDTO
     * @return 返回id
     */
    Integer save(StoreDTO storeDTO);

    Integer update(StoreDTO storeDTO);

    /**
     * 该分组下门店的个数
     * @param storeGroupId
     * @return
     */
    Integer countByGroupId(Integer storeGroupId);

    /**
     * 修改门店分组
     * @param oldStoreGroupId
     * @param newStoreGroupId
     * @return
     */
    Integer updateGroupId(Integer oldStoreGroupId, Integer newStoreGroupId);

    StoreDTO getById(Integer storeId);

    /**
     * 查询使用了该品牌的门店个数
     * @param brandId
     * @return
     */
    Integer countByBrandId(Integer brandId);

    /**
     * 查询如企业下门店关联主键的个数
     * @param enterpriseId
     * @param storeCode
     * @param storeId  如果id不为null， 会查询storeId不为传入参数的数据；如果id为null， 会略过
     * @return
     */
    Integer countByStoreCode(Integer enterpriseId, String storeCode, Integer storeId);

    Page<StoreDTO> listStore(StoreSearchDBDTO storeDTO, Integer pageNum, Integer pageSize);

    /**
     * 返回状态
     * @param storeDTO
     * @return
     */
    Integer checkCompleteStatus(StoreDTO storeDTO);

    int updateStoreGroupId(Integer storeId, Integer groupId);

    Integer countByStoreName(Integer enterpriseId, String storeName, Integer storeId);
    int bulkUpdateStoreStatus(String storeIds, Integer enterpriseId, String value);

    int bulkUpdateStoreConactsPhone(String storeIds, Integer enterpriseId, String value);

    int bulkUpdateStoreBusinessTime(String storeIds, Integer enterpriseId, String value);

    int bulkUpdateStorePhoto(String storeIds, Integer enterpriseId, String value);

    int bulkAddStorePhoto(String storeIds, Integer enterpriseId, String value);

    int bulkUpdateStoreBrands(String storeIds, Integer enterpriseId, String value);

    int bulkUpdateStoreGroup(String storeIds, Integer enterpriseId, Integer value);

    StoreDTO getByStoreNameAndStoreCode(Integer enterpriseId, String storeName, String storeCode);

    List<Integer> listAllStoreId(Integer enterpriseId);

    boolean validateStoreCodeIsExist(Integer enterpriseId, Integer regionId, String storeCode, Integer storeId);

    boolean validateStoreNameIsExist(Integer enterpriseId, Integer regionId, String storeName, Integer storeId);

    int authAddStore(StoreDTO storeDTO);

    List<Integer> listStoreIdByFromEnterpriseId(Integer fromEnterpriseId);

    int cancelAuthStore(List<Integer> storeInfoIdList, Integer toEnterpriseId);

    Integer getStoreOwnerByStoreInfoId(Integer enterpriseId, Integer storeInfoId);

    Integer getStoreIdByStoreInfoId(Integer enterpriseId, Integer storeInfoId);

    String listStoreInfoIdByStoreIds(String storeIds, Integer enterpriseId);
}
